@@ -322,8 +322,10 @@ class PaasDispatcher:
                             job_handle, launch_time,
                             job_handle.paas_resource.weight)
             elif status is JobEventType.LAUNCH_FAILED:
-                self.potential_concurrency -= 1
-                self.potential_weight -= job_handle.expected_weight
+                if job_handle.paas_resource is None:
+                    # otherwise decrements will be done after decommission
+                    self.potential_concurrency -= 1
+                    self.potential_weight -= job_handle.expected_weight
                 self.pending_jobs.pop(job_handle, None)
                 logger.error("Failed to launch %s", job_handle)
                 self.total_job_launches += 1
@@ -333,8 +335,10 @@ class PaasDispatcher:
             elif status is JobEventType.COORDINATOR_REPORT_FAILED:
                 # event supersedes LAUNCH_FAILED (adds info that reporting
                 # the failure itself failed)
-                self.potential_concurrency -= 1
-                self.potential_weight -= job_handle.expected_weight
+                if job_handle.paas_resource is None:
+                    # otherwise decrements will be done after decommission
+                    self.potential_concurrency -= 1
+                    self.potential_weight -= job_handle.expected_weight
                 self.pending_jobs.pop(job_handle, None)
                 logger.error("Failed to launch %s and even report it "
                              "to coordinator", job_handle)
